Imports Navigation

Namespace Survey.Test
    <TestClass(), DeploymentItem("Survey\StateInfo.config")>
    Public Class SurveyControllerTest
        <TestMethod()>
        Public Sub UpdateQuestion1NavigatesToQuestion2IfAnswerIsWebForms()
            StateController.Navigate("Survey")
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "Web Forms"}

            controller.UpdateQuestion1(question)

            Assert.AreEqual("Question2", StateContext.State.Key)
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion1NavigatesToThanksIfAnswerIsMVC()
            StateController.Navigate("Survey")
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "MVC"}

            controller.UpdateQuestion1(question)

            Assert.AreEqual("Thanks", StateContext.State.Key)
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion1PassesTechnologyAnswer()
            StateController.Navigate("Survey")
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "Web Forms"}

            controller.UpdateQuestion1(question)

            Assert.AreEqual("Web Forms", CStr(StateContext.Data("technology")))
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion1StoresAnswer()
            StateController.Navigate("Survey")
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "Web Forms"}

            controller.UpdateQuestion1(question)

            Assert.AreEqual("Web Forms", CStr(StateController.Crumbs(0).Data("answer")))
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion2NavigatesToThanks()
            StateController.Navigate("Survey")
            StateController.Navigate("Next", New NavigationData From {{"technology", "Web Forms"}})
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "Yes"}

            controller.UpdateQuestion2(question)

            Assert.AreEqual("Thanks", StateContext.State.Key)
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion2PassesNavigationTrueIfAnswerYes()
            StateController.Navigate("Survey")
            StateController.Navigate("Next", New NavigationData From {{"technology", "Web Forms"}})
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "Yes"}

            controller.UpdateQuestion2(question)

            Assert.AreEqual(True, CBool(StateContext.Data("navigation")))
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion2PassesNavigationFalseIfAnswerNo()
            StateController.Navigate("Survey")
            StateController.Navigate("Next", New NavigationData From {{"technology", "Web Forms"}})
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "No"}

            controller.UpdateQuestion2(question)

            Assert.AreEqual(False, CBool(StateContext.Data("navigation")))
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion2PassesTechnologyAnswerPassedIn()
            StateController.Navigate("Survey")
            StateController.Navigate("Next", New NavigationData From {{"technology", "Web Forms"}})
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "No"}

            controller.UpdateQuestion2(question)

            Assert.AreEqual("Web Forms", CStr(StateContext.Data("technology")))
        End Sub

        <TestMethod()>
        Public Sub UpdateQuestion2StoresAnswer()
            StateController.Navigate("Survey")
            StateController.Navigate("Next", New NavigationData From {{"technology", "Web Forms"}})
            Dim controller As New SurveyController
            Dim question As New Question With {.Answer = "Yes"}

            controller.UpdateQuestion1(question)

            Assert.AreEqual("Yes", CStr(StateController.Crumbs(1).Data("answer")))
        End Sub
    End Class
End Namespace
